@@ -175,6 +175,10 @@ def expand_manifest(manifest, client):
             account_id = account.get("account_id")
             logger.info("Found an account: {}".format(account_id))
             expanded_account = expand_account(account, client, account_id, manifest)
+            if expanded_account is None:
+                raise Exception(
+                    f"You have listed account: {account_id} which is not ACTIVE"
+                )
             temp_accounts.append(expanded_account)
         elif account.get("ou"):
             ou = account.get("ou")
